/*
*	lcd.h : some useful defines for the Cobalt LCD driver
*
*	Copyright 1996-99, Cobalt Networks, Inc.
*
*	By: Andrew Bose	
*           Timothy Stonis (x86 version)
*
* NOTE: make sure that this is useable from both kernel and user space
* 
*/
#ifndef _COBALT_LCD_H
#define _COBALT_LCD_H

#define LCD_CHARS_PER_LINE 40
#define MAX_IDLE_TIME 120

struct lcd_display {
        unsigned long buttons;
        int size1;
        int size2;
        unsigned char line1[LCD_CHARS_PER_LINE];
        unsigned char line2[LCD_CHARS_PER_LINE];
        unsigned char cursor_address;
        unsigned char character;
        unsigned char leds;
        unsigned char *RomImage;
};

/* the leds */
#define LED_SHUTDOWN          (1 << 0)
#define LED_WEBLIGHT          (1 << 1)
#define LED_COBALTLOGO        (1 << 2)

/* 
 * Function command codes for io_ctl.
 */
#define LCD_On			1
#define LCD_Off			2
#define LCD_Clear		3
#define LCD_Reset		4
#define LCD_Cursor_Left		5
#define LCD_Cursor_Right	6
#define LCD_Disp_Left		7
#define LCD_Disp_Right		8
#define LCD_Get_Cursor		9
#define LCD_Set_Cursor		10
#define LCD_Home		11
#define LCD_Read		12		
#define LCD_Write		13	
#define LCD_Cursor_Off		14
#define LCD_Cursor_On		15
#define LCD_Get_Cursor_Pos	16
#define LCD_Set_Cursor_Pos	17
#define LCD_Blink_Off           18
#define LCD_Raw_Inst		19
#define LCD_Raw_Data		20

// LED controls
#define LED_Set			40	
#define LED_Bit_Set		41
#define LED_Bit_Clear		42

//  Button defs
#define BUTTON_Read             50  
#define BUTTON_Next               0x3D
#define BUTTON_Next_B             0x7E
#define BUTTON_Reset_B            0xFC

#ifdef __KERNEL__
extern void lcd_led_set(const unsigned char);
extern unsigned char lcd_led_get(void);
#endif

#endif
